@@ -115,6 +115,10 @@ class Sentry(object):
 
     @property
     def last_event_id(self):
+        try:
+            return g.sentry_event_id
+        except Exception:
+            pass
         return getattr(self, '_last_event_id', None)
 
     @last_event_id.setter
@@ -212,6 +216,10 @@ class Sentry(object):
 
     def before_request(self, *args, **kwargs):
         self.last_event_id = None
+
+        if request.url_rule:
+            self.client.transaction.push(request.url_rule.rule)
+
         try:
             self.client.http_context(self.get_http_info(request))
         except Exception as e:
@@ -225,6 +233,8 @@ class Sentry(object):
         if self.last_event_id:
             response.headers['X-Sentry-ID'] = self.last_event_id
         self.client.context.clear()
+        if request.url_rule:
+            self.client.transaction.pop(request.url_rule.rule)
         return response
 
     def init_app(self, app, dsn=None, logging=None, level=None,
