@@ -30,6 +30,6 @@ def logging_request_exc(request):
     logger = logging.getLogger(__name__)
     try:
         raise Exception(request.GET.get('message', 'view exception'))
-    except Exception, e:
+    except Exception as e:
         logger.error(e, exc_info=True, extra={'request': request})
     return HttpResponse('')
